TableMethods

Struct TableMethods 

pub struct TableMethods<'a, C>
where C: 'a,
{ /* private fields */ }
A builder providing access to all methods supported on table resources. It is not used directly, but through the Area120Tables hub.

Example

Instantiate a resource builder

extern crate hyper;
extern crate hyper_rustls;
extern crate google_area120tables1_alpha1 as area120tables1_alpha1;

use area120tables1_alpha1::{Area120Tables, FieldMask, hyper_rustls, hyper_util, yup_oauth2};

let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
    .with_native_roots()
    .unwrap()
    .https_only()
    .enable_http2()
    .build();

let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
    secret,
    yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
    yup_oauth2::client::CustomHyperClientBuilder::from(
        hyper_util::client::legacy::Client::builder(executor).build(connector),
    ),
).build().await.unwrap();

let client = hyper_util::client::legacy::Client::builder(
    hyper_util::rt::TokioExecutor::new()
)
.build(
    hyper_rustls::HttpsConnectorBuilder::new()
        .with_native_roots()
        .unwrap()
        .https_or_http()
        .enable_http2()
        .build()
);
let mut hub = Area120Tables::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `get(...)`, `list(...)`, `rows_batch_create(...)`, `rows_batch_delete(...)`, `rows_batch_update(...)`, `rows_create(...)`, `rows_delete(...)`, `rows_get(...)`, `rows_list(...)` and `rows_patch(...)`
// to build up your call.
let rb = hub.tables();

Implementations

Source

impl<'a, C> TableMethods<'a, C>

pub fn rows_batch_create( &self, request: BatchCreateRowsRequest, parent: &str, ) -> TableRowBatchCreateCall<'a, C>

Create a builder to help you perform the following task:

Creates multiple rows.

Arguments
  • request - No description provided.
  • parent - Required. The parent table where the rows will be created. Format: tables/{table}
pub fn rows_batch_delete( &self, request: BatchDeleteRowsRequest, parent: &str, ) -> TableRowBatchDeleteCall<'a, C>

Create a builder to help you perform the following task:

Deletes multiple rows.

Arguments
  • request - No description provided.
  • parent - Required. The parent table shared by all rows being deleted. Format: tables/{table}
pub fn rows_batch_update( &self, request: BatchUpdateRowsRequest, parent: &str, ) -> TableRowBatchUpdateCall<'a, C>

Create a builder to help you perform the following task:

Updates multiple rows.

Arguments
  • request - No description provided.
  • parent - Required. The parent table shared by all rows being updated. Format: tables/{table}
pub fn rows_create( &self, request: Row, parent: &str, ) -> TableRowCreateCall<'a, C>

Create a builder to help you perform the following task:

Creates a row.

Arguments
  • request - No description provided.
  • parent - Required. The parent table where this row will be created. Format: tables/{table}
pub fn rows_delete(&self, name: &str) -> TableRowDeleteCall<'a, C>

Create a builder to help you perform the following task:

Deletes a row.

Arguments
  • name - Required. The name of the row to delete. Format: tables/{table}/rows/{row}
pub fn rows_get(&self, name: &str) -> TableRowGetCall<'a, C>

Create a builder to help you perform the following task:

Gets a row. Returns NOT_FOUND if the row does not exist in the table.

Arguments
  • name - Required. The name of the row to retrieve. Format: tables/{table}/rows/{row}
pub fn rows_list(&self, parent: &str) -> TableRowListCall<'a, C>

Create a builder to help you perform the following task:

Lists rows in a table. Returns NOT_FOUND if the table does not exist.

Arguments
  • parent - Required. The parent table. Format: tables/{table}
pub fn rows_patch(&self, request: Row, name: &str) -> TableRowPatchCall<'a, C>

Create a builder to help you perform the following task:

Updates a row.

Arguments
  • request - No description provided.
  • name - The resource name of the row. Row names have the form tables/{table}/rows/{row}. The name is ignored when creating a row.
pub fn get(&self, name: &str) -> TableGetCall<'a, C>

Create a builder to help you perform the following task:

Gets a table. Returns NOT_FOUND if the table does not exist.

Arguments
  • name - Required. The name of the table to retrieve. Format: tables/{table}
pub fn list(&self) -> TableListCall<'a, C>

Create a builder to help you perform the following task:

Lists tables for the user.